#

##

##

    	natures

    	description

    		This has part of the data about each
    		grocery treasure.

    	structure

    		{
    			"natures": [
    				{
    					#
    					#	This is the number of packages.
    					#
    					"amount": "1",

    					"identity": {
    						"name": "ASPARAGUS",
    						"FDC ID": "2390911",
    						"UPC": "07789048861",
    						"DSLD ID": ""
    					}
    				}
    			]
    		}